import argparse
from abcli import file
from . import *
from abcli.logger import logger
from blueness.argparse.generic import sys_exit


parser = argparse.ArgumentParser(NAME)
parser.add_argument(
    "task",
    type=str,
    default="get",
    help="get|add_signature",
)
parser.add_argument(
    "--application",
    type=str,
    default="",
)
parser.add_argument(
    "--delim",
    type=str,
    default=", ",
)
parser.add_argument(
    "--header",
    type=str,
    default="",
    help="this|that",
)
parser.add_argument(
    "--filename",
    type=str,
    default="",
)
parser.add_argument(
    "--footer",
    type=str,
    default="",
    help="this|that",
)
parser.add_argument(
    "--item_name",
    default="tag",
    type=str,
)
parser.add_argument(
    "--log",
    default=1,
    type=int,
    help="0|1",
)
parser.add_argument(
    "--word_wrap",
    default=0,
    type=int,
    help="0|1",
)
parser.add_argument(
    "--name",
    type=str,
    default=".",
)
parser.add_argument(
    "--keyword",
    type=str,
    help="name|tags",
)
args = parser.parse_args()

delim = " " if args.delim == "space" else args.delim

success = False
output = None
if args.task == "get":
    if args.keyword == "name":
        print(get_name())
        success = True
    elif args.keyword == "tags":
        from abcli.plugins import tags

        output = tags.get(args.name if args.name not in ",.".split(",") else get_name())
        success = True
    else:
        logger.error(f"-{NAME}: get: {args.keyword}: unknown keyword.")
        print("unknown")
elif args.task == "add_signature":
    import numpy as np

    success, image = file.load_image(args.filename)
    if success:
        from abcli.plugins.graphics import add_signature
        from abcli.modules.objects import signature as header

        success = file.save_image(
            args.filename,
            add_signature(
                image,
                [args.header] + [" | ".join(header())],
                [args.footer] + [" | ".join([args.application] + signature())],
                word_wrap=args.word_wrap,
            ),
        )

    if success:
        logger.info(
            f"{NAME}.add_signature({args.filename},{args.header},{args.footer})"
        )
else:
    success = None

if success == True and output is not None:
    if args.log:
        logger.info(f"{len(output):,} {args.item_name}(s): {delim.join(output)}")
    else:
        print(delim.join(output))

sys_exit(logger, NAME, args.task, success, log=args.log)



from abcli import path
from abcli.modules import objects


def test_object_path():
    object_name = objects.unique_object()
    object_path = objects.object_path(object_name, create=True)
    assert object_path
    assert path.exist(object_path)


def test_unique_object():
    prefix = "prefix"
    object_name = objects.unique_object(prefix)
    assert object_name
    assert object_name.startswith(prefix)



from abcli import NAME, VERSION, DESCRIPTION, REPO_NAME
from blueness.pypi import setup

setup(
    filename=__file__,
    repo_name=REPO_NAME,
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    packages=[
        NAME,
        f"{NAME}.bash",
        f"{NAME}.file",
        f"{NAME}.keywords",
        f"{NAME}.options",
        f"{NAME}.path",
        f"{NAME}.modules",
        f"{NAME}.modules.host",
        f"{NAME}.plugins",
        f"{NAME}.plugins.cache",
        f"{NAME}.plugins.graphics",
        f"{NAME}.plugins.git",
        f"{NAME}.plugins.gpu",
        f"{NAME}.plugins.metadata",
        f"{NAME}.plugins.relations",
        f"{NAME}.plugins.storage",
        f"{NAME}.plugins.tags",
        f"{NAME}.string",
        f"{NAME}.table",
        f"{NAME}.tests",
    ],
    package_data={
        NAME: [
            "config.env",
            ".abcli/**/*.sh",
            "assets/**/*",
        ],
    },
)



import os
from abcli import env
from abcli import file


def test_abcli_env():
    assert env.HOME
    assert env.abcli_path_git
    assert env.abcli_path_storage

    assert env.ABCLI_AWS_RDS_DB
    assert env.ABCLI_AWS_RDS_PORT
    assert env.ABCLI_AWS_RDS_USER



import os
import time

# https://en.wikipedia.org/wiki/List_of_tz_database_time_zones
# Toronto: "America/New_York"
os.environ["TZ"] = "America/Los_Angeles"
time.tzset()

NAME = "abcli.string"

from .constants import *
from .functions import *



from typing import List
import glob
import os
from abcli import env, path, file


def get_plugin_name(repo_name: str) -> str:
    return "abcli" if repo_name == "awesome-bash-cli" else repo_name.replace("-", "_")


def get_module_name(repo_name: str) -> str:
    list_of_candidates = sorted(
        file.path(filename)
        for filename in glob.glob(
            os.path.join(env.abcli_path_git, repo_name, "**/__init__.py"),
            recursive=True,
        )
    )

    if not list_of_candidates:
        return "no-module-found"

    return path.name(list_of_candidates[0])


def list_of_external(repo_names=False) -> List[str]:
    output = sorted(
        [
            repo_name
            for repo_name in [
                path.name(path_)
                for path_ in glob.glob(os.path.join(env.abcli_path_git, "*/"))
            ]
            if repo_name != "awesome-bash-cli"
            and path.exist(
                os.path.join(
                    env.abcli_path_git,
                    repo_name,
                    get_module_name(repo_name),
                    ".abcli",
                )
            )
        ]
    )

    if not repo_names:
        output = [repo_name.replace("-", "_") for repo_name in output]

    return output
